@@ -238,16 +238,6 @@ func (s *CheServerReconciler) getUserCommonPolicies() []rbacv1.PolicyRule {
 			Resources: []string{"configmaps"},
 			Verbs:     []string{"get", "list", "create", "update", "patch", "delete"},
 		},
-		{
-			APIGroups: []string{""},
-			Resources: []string{"events"},
-			Verbs:     []string{"watch"},
-		},
-		{
-			APIGroups: []string{"apps"},
-			Resources: []string{"secrets"},
-			Verbs:     []string{"list"},
-		},
 		{
 			APIGroups: []string{"apps"},
 			Resources: []string{"deployments"},
@@ -258,11 +248,6 @@ func (s *CheServerReconciler) getUserCommonPolicies() []rbacv1.PolicyRule {
 			Resources: []string{"replicasets"},
 			Verbs:     []string{"get", "list", "patch", "delete"},
 		},
-		{
-			APIGroups: []string{"extensions"},
-			Resources: []string{"ingresses"},
-			Verbs:     []string{"get", "list", "watch", "create", "delete"},
-		},
 		{
 			APIGroups: []string{"networking.k8s.io"},
 			Resources: []string{"ingresses"},
