@@ -312,90 +312,6 @@ func TestUpdateIntegrationServerEndpoints(t *testing.T) {
 	}
 }
 
-func TestShouldSetUpCorrectlyDevfileRegistryURL(t *testing.T) {
-	type testCase struct {
-		name         string
-		initObjects  []runtime.Object
-		cheCluster   *chev2.CheCluster
-		expectedData map[string]string
-	}
-
-	testCases := []testCase{
-		{
-			name: "Test #1",
-			cheCluster: &chev2.CheCluster{
-				ObjectMeta: metav1.ObjectMeta{
-					Namespace: "eclipse-che",
-				},
-				Spec: chev2.CheClusterSpec{
-					Components: chev2.CheClusterComponents{
-						DevfileRegistry: chev2.DevfileRegistry{
-							DisableInternalRegistry: true,
-							ExternalDevfileRegistries: []chev2.ExternalDevfileRegistry{
-								{Url: "external-plugin-registry"},
-							},
-						},
-					},
-				},
-			},
-			expectedData: map[string]string{
-				"CHE_WORKSPACE_DEVFILE__REGISTRY__URL":           "external-plugin-registry",
-				"CHE_WORKSPACE_DEVFILE__REGISTRY__INTERNAL__URL": "",
-			},
-		},
-		{
-			name: "Test #2",
-			cheCluster: &chev2.CheCluster{
-				ObjectMeta: metav1.ObjectMeta{
-					Namespace: "eclipse-che",
-				},
-				Spec: chev2.CheClusterSpec{
-					Components: chev2.CheClusterComponents{
-						DevfileRegistry: chev2.DevfileRegistry{
-							ExternalDevfileRegistries: []chev2.ExternalDevfileRegistry{
-								{Url: "external-plugin-registry"},
-							},
-						},
-					},
-				},
-				Status: chev2.CheClusterStatus{
-					DevfileRegistryURL: "internal-plugin-registry",
-				},
-			},
-			expectedData: map[string]string{
-				"CHE_WORKSPACE_DEVFILE__REGISTRY__URL":           "internal-plugin-registry external-plugin-registry",
-				"CHE_WORKSPACE_DEVFILE__REGISTRY__INTERNAL__URL": "http://devfile-registry.eclipse-che.svc:8080",
-			},
-		},
-		{
-			name: "Test devfile registry urls #5",
-			cheCluster: &chev2.CheCluster{
-				ObjectMeta: metav1.ObjectMeta{
-					Namespace: "eclipse-che",
-				},
-				Status: chev2.CheClusterStatus{
-					DevfileRegistryURL: "internal-plugin-registry",
-				},
-			},
-			expectedData: map[string]string{
-				"CHE_WORKSPACE_DEVFILE__REGISTRY__INTERNAL__URL": "http://devfile-registry.eclipse-che.svc:8080",
-				"CHE_WORKSPACE_DEVFILE__REGISTRY__URL":           "internal-plugin-registry",
-			},
-		},
-	}
-
-	for _, testCase := range testCases {
-		t.Run(testCase.name, func(t *testing.T) {
-			ctx := test.GetDeployContext(testCase.cheCluster, []runtime.Object{})
-
-			server := NewCheServerReconciler()
-			actualData, err := server.getCheConfigMapData(ctx)
-			assert.Nil(t, err)
-			test.ValidateContainData(actualData, testCase.expectedData, t)
-		})
-	}
-}
-
 func TestShouldSetUpCorrectlyPluginRegistryURL(t *testing.T) {
 	type testCase struct {
 		name         string
